package internal

import (
	"fmt"
	"xg_dba/internal/controllers/connect"
	"xg_dba/internal/controllers/system"
	"xg_dba/internal/global"

	"github.com/gin-gonic/gin"
)

// SetupRouter 配置Gin路由
func SetupRouter() *gin.Engine {
	r := gin.Default()
	// 静态文件服务配置
	configureStaticFileServing(r)
	configureRootHandler(r)
	public := r.Group("/api")
	{
		//public.POST("/register", connect.SaveConnectInfo_controller)

		//连接信息 (服务器，数据库)
		public.GET("/GetConnectInfo", connect.GetConnectInfo_controller)
		public.POST("/AddConnectInfo", connect.AddConnectInfo_controller)

		//服务器信息
		public.POST("/GetSingleSystemInfo", system.GetSingleSystemInfo_controller)
		public.POST("/SetSystemInfo", system.SetSystemInfo_controller)
		public.GET("/GetSystemInfoProgress", system.GetSystemInfoProgress_controller)
	}
	return r
}

// HttpController 启动 HTTP 服务器
func HttpController() {
	r := SetupRouter()
	ipPort := fmt.Sprintf("%s:%s", global.Cfg.App.Ip, global.Cfg.App.Port)
	fmt.Println("ipPort:", ipPort)
	err := r.Run(ipPort)
	if err != nil {
		panic(err)
	}
	global.Logger.Info("Server is running on port", fmt.Sprintf("%s:%s", global.Cfg.App.Ip, global.Cfg.App.Port))

}

// configureStaticFileServing 配置静态文件服务
func configureStaticFileServing(r *gin.Engine) {
	r.Static("/static", "./static")
}

// configureRootHandler 配置根路径请求处理
func configureRootHandler(r *gin.Engine) {
	r.GET("/", func(c *gin.Context) {
		c.File("./static/index.html")
	})
}
